@@ -9,7 +9,6 @@ import os
 import re
 import redis
 import requests
-import signal
 import sys
 import time
 import uuid
@@ -141,11 +140,6 @@ def delete_all_files(top):
             os.remove(path)
 
 
-def signal_handler(signal, frame):
-    logger.warning("Interrupt. Shuting down.")
-    sys.exit(0)
-
-
 def run():
     setup_logger()
     logger.info('Started')
@@ -156,7 +150,6 @@ def run():
         delete_all_files(FRAMES_PATH)
         observer.schedule(event_handler, path=FRAMES_PATH, recursive=True)
         observer.start()
-        signal.signal(signal.SIGINT, signal_handler)
 
         while True:
             time.sleep(1)
@@ -165,13 +158,15 @@ def run():
                 logger.warning("No events received in the last minute.")
                 # Sometimes watchdog stops receiving events.
                 # We exit, so the process can be restarted.
-                sys.exit(1)
-    except KeyboardInterrupt:
-        logger.warning("Keyboard interruption. Shuting down.")
+                break
+    except KeyboardInterrupt as err:
+        logger.warning("Keyboard interruption")
     except Exception as err:
-        logger.error(err)
+        logger.exception(err)
     finally:
-        observer.join()
+        observer.stop()
+    observer.join()
+    logger.warning("Bye")
 
 
 if __name__ == "__main__":
